@@ -25,7 +25,7 @@ class RawOperator:
     MATCH = "~"
 
     equal_not_required = [EQ, NEQ, MATCH]
-    equal_is_possible = [GT, LT]
+    equal_is_possible = [GT, LT]  # operators with possible equal sign as second symbol
 
     EQUAL_SIGN = "="
 
@@ -117,14 +117,12 @@ class ExpressionNode(BaseNode):
 
     operator: Operator
 
-
     is_expression_node = True
 
     def pprint(self, pad=0):
         print(" " * pad + str(self.operator) + " " + str(self.value))
 
 
-
 def simplify(tree: BaseNode) -> BaseNode:
     """
     Merge nested ORs and ANDs
